bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 9. Aventiure
___________________________________________________ #### Auentv wie Sivrit ze Wormez in botschefte fvor
| ### Do> si gevarn warn vollen niwen tage ### do sprach der chvne Hagene nv merchet waz ih sage ### ir svomt ivch mit den mæren ze Wormeze an den Rin ### die iwern boten solden nv zen Burgonden sin
###### 538 | ### Do sprach der kunich Gvnther ir habt mir reht geseit ### nv hereitet ivch zer verte ritter vil gemeit ### wande wir in disen ziten ander niemen han ### der dar mvge geriten do sprach der vbermvete man
###### 539 | ### Nv wizzet lieber herre ine bin niht bote gvot ### ich wil ivch eins bewisen der ez doch gerne tvot ### Sivrit den chvnen svlt ir iz niht verdagen ### dvrch iwer swester liebe getarrer erz iv nimmer versagen
###### 540 | ### Er sande nach dem rechen der herre chom zehant ### er sprach sit daz wir nahen heim in miniv lant ### so solde ich boten senden der lieben swester min ### vn– ovch miner mvoter daz wir nv nahen an den Rin
###### 541 | ### Des bitte ich ivch her Sivrit daz ir die reise tvot ### daz ez mit mir verdiene div edel maget gvot ### mit allen minen frivnden ritter vil gemeit ### do sprach der degen chvne der reise bin ich iv bereit
| ### Nv enbietet swaz ir wellet des wirdet niht verdaget ### dvrch die vil minneklichen so wirt ez gar gesaget ### zwiv solde ih dir verzihen die ich in hercen han ### swaz ir durch si gebietet daz ist allez getan
###### 543 | ### So sagt miner mvoter vn– ovch der swester min ### daz wir an dirre verte in hohem mvote sin ### lat wizzen [21r]mine brveder wie wir geworben han ### vn– ander unser frivnde sol man div mære ovch horen lan
###### 544 | ### Chriemhilde vn– mine mvoter svlt ir niht verdagen ### min vn– Prvnh' dienest svlt ir in beiden sagen ### vn– allem ir gesinde vn– allen minen man ### dar nach ie ranc min herce wie wol ich daz erworben han
###### 545 | ### Vn– sagt ovch minen brvdern vn– andern frivnden min ### daz si mit grozem vlize dar zv gewarnt sin ### vn– sol in vnsern landen div mære wizzen lan ### ich wil mit Prvnhilde vil groze hochgecite han
###### 546 | ### Vn– bitet mine swester so si daz habe vernomen ### daz ich mit minen gesten si ze lande chomen ### daz si mit vlize enpfahe die trvtinne min ### daz wil immer mere mit triwen dienende sin
| ### Do der vil chvne reche vrlovp von im genam ### vn– ovch von Prvnhilde der ritter lobesam ### reit in grozen frevden ze Wormeze an den Rin ### ez enchunde in allen landen ein bote bezzer niht gesin
###### 548 | ### Mit vier vn– zweinzech rechen ze Wormeze er do reit ### des chvniges chom er ane do daz wart geseit ### allez daz gedigene vor iamer heten not ### si vorhten daz ir herre dort beliben wære tot
###### 549 | ### Die helde erbeizet waren vil hohe stvont ir mvot ### vil schier in chomen beide die ivnge kvnige gvot ### vn– al daz hofegesinde der herre Gernot sprach ### do er sinen <brvder> niht bi Sivride ensach
###### 550 | ### Willechomen ritter edele ir svlt vns hoeren lan ### wa ir minen brvder <den> kunic habt verlan ### div Prvnhilde sterche in wæn vns hat benomen ### so ist vns ir hohiv minne harte schedelich chomen
| ### Iv edeln rechen beiden vn– al den magen sin ### enbivtet sinen dienest der hergeselle min ### den liez ih wol gesunden er hat mich her gesant ### ze boten mit den mæren daz ich iv div tæte <bekant>
###### 552 | ### Ir svlt daz ahten schiere swie so daz geschehe ### daz ich iwer mvoter vn– iwer swester sehe ### die sol ich lazen horen waz in enboten hat ### Gunther der chvnic riche des dinch in hohen eren stat
###### 553 | ### Do sprach der ivnge Giselher da svlt ir dar gan ### da habt ir miner mvoter vil liebe an getan ### div hat doch michel sorge vmbe den brvoder min ### si sehent ivch beide gerne des svlt ir gar ane angest sin
###### 554 | ### Do sprach der herre Sivrit swaz ich in dienen chan ### daz sol vil willechlichen mit triwen sin getan ### wer sagt nv den frowen daz ich wil dar gan ### daz tvon ich sprach do Giselher der vil wætlich man
| ### Der stolze chvene reche ze siner mvoter sprach ### vn– ovch zv siner swester da er si beide sach ### vns ist chomen Sivrit der helt vz Niderlant ### in hat min brvoder Gunther ze Rine her von im gesant
###### 556 | ### Er bringet vns div mære wiez vmben chvnich ste ### nv svlt ir im erlovben daz er ze hove ge ### er bringet div rehten mære her von Islant ### noch was den ede[21v]len frowen vil michel sorgen bechant
###### 557 | ### Si sprvngen nach ir wæte do leiten si sich an ### si baten Sivride do hin ze hove gan ### daz tet er willechliche wand er si gerne sach ### Chriemhilt div vil schone zvo zim do gvetlichen sprach
###### 558 | ### Sit willechomen herre Sivrit ritter lobelich ### war ist chomen min brvoder Gvnther der kunic rich ### von Prvnhilde sterche den wæn wir haben verlorn ### owe mir armen meide daz ih danne ie wart geborn
| ### Do sprach der ritter chvene nv gebt mir botenbrot ### ir edeln ivncfrowen ir wænet ane not ### ich liez in wol gesunden daz tvn ich iv bechant ### er vn– div schone Prvnhilt hant mich iv beiden her gesant
###### 560 | ### Si enbietent iv ir dienest mit triwen in daz lant ### vil richiv kuniginne daz tvon ih iv bechant ### nv lazet iwer weinen si wellent schiere chomen ### sine het in langen citen so lieber mære niht vernomen
###### 561 | ### Mit sneblanchen geren ir ovgen wolgetan ### wischte si nah trehenen danchen si began ### dem boten dirre mære div ir da waren chomen ### do was ir michel trvoren vn– ovch ir weinen benomen
###### 562 | ### Den boten bat man sizzen des was er bereit ### do sprach div ivncfrowe mir wære niht ze leit ### ob ich ze botenmiete iv solde gebn min golt ### dar zvo sit ir ze riche ich wil iv svs immer wesn holt
###### 563 | ### Ob ich nv eine hete sprach er drizzech lant ### so enpfienge ich doch vil gerne gabe vz iwer hant ### do sprach div minnekliche nv sol ez sin getan ### si hiez ir kamærære nach der botenmiete gan
| ### Vier vn– zweinzich povge mit gesteine gvot ### die gab si im ze miete do stvnt also sin mvot ### ern woldes niht behalden er gab ez sa zehant ### ir nehstem ingesinde die cr zer chemenaten vant
###### 565 | ### Ir mvter bot ir dienest in gvtlichen an ### ich sol iv sagen mere sprach do der chvene man ### wes ivch der kunich bitet swenner nv chvmet her ### daz weller immer dienen daz ir leistet sinen ger
###### 566 | ### Die sine <richen> geste bitet er ivch wol enpfan ### des manter iwer vil sere irn svlt des ovch niht lan ### irn <ritet> im zegegene fvr <Wormez> vf den sant ### des sit ir von dem kunige mit grozen triwen gemant
###### 567 | ### Do sprach div minnekliche des bin ich vil bereit ### swaz ich im kan gedienen daz ist im vnverseit ### in vrivntlichen triwen so sol ez sin getan ### do merte sich ir varwe die si vor liebe do gewan
| ### Ez enwart nie bote enpfangen deheines fvrsten baz ### getorste si in chvssen div frowe tæte daz ### wie rehte minnekliche er von den frowen schiet ### do taten Bvrgonden als in Sivrit do geriet
###### 569 | ### Sindolt vn– Hvnolt vn– Rvmolt der degen ### die mvsen vil vnmvoze zvo den citen pflegen ### rihten daz gesidele als in daz was bechant ### des kuniges ambetlvte man do mit arebeiten vant
###### 570 | ### <Ortwin> vn– Gere des [22r]rechen kvniges man ### die sanden allenthalben nach den frivnden dan ### vn– chvnten in die hochgecite div da solde sin ### da bereiten sich engegene div vil schoenen magedin
###### 571 | ### Der palas vn– die wende was allez vber al ### gezieret gegen den gesten der Gvnthers sal ### wart vil wol bezimbert dvrch manigen vremden man ### div selbe groze hochgecite hvop vil vrolichen an
| ### Do riten allenthalben die wege dvrch daz lant ### der drier kunige mage die het man besant ### daz si den solden warten die in da wolden chomen ### do wart vz den chisten richer wæte vil genomen
###### 573 | ### Do sagt man div mære daz man nv riten sach ### den chvnich mit sinen gesten do hvop sich vngemach ### von des volches chreften in Burgonden lant ### hey waz man sneller degene bi frowen Prvnhilde vant
###### 574 | ### Do sprach div schone Chriemhilt ir miniv mægedin ### di an dem antpfange mir mir wellen sin ### die svochen vz den chisten div aller besten chleit ### di si mvgen vinden daz si den frowen ovch geseit
###### 575 | ### Do chomen ovch die rechen die hiezen tragen dar ### die herlichen sætele nach rotem golde var ### die frowen solden riten ze Wormeze an den Rin ### bezzir pferit gereite chvnde ninder gesin
###### 576 | ### Hey was da liehtes goldes von <den> moren schein ### ovch lagen an den zovmen vil manic edel stein ### die gvldinen schemil ob liehten pfellen gvot ### braht man dar den frowen si waren hoh gemvot
| ### Begvrtet mit den siden vil schoen vn– starch ### braht man den frowen vil wnneklichiv march ### div richen fvrbvege sach man div more tragen ### von den besten siden da von iv iemen chvnde sagen
###### 578 | ### Sehs vn– ahzech frowen hiez man chomen dan ### die gebende trvogen zv Chriemhilde stan ### chomen di vil schonen vn– heten liehtiv chleit ### do wart ovch wol gezieret vil manich minneklichiv meit
###### 579 | ### Fvnfzech vn– viere von Buregonden lant ### so waren ez die beste die man ze hove vant ### di sah man <valevahsen> vnder liehten porten gan ### <des> Gvnther an si gerte daz wart mit vlize getan
###### 580 | ### Von liehten richen pfellen verre voz heiden lant ### si trvgen vor den gesten so manic gvot gewant ### daz ir genvoge schoene ze rehte wol gezam ### er wære in swachem mvote der ir deheiner wære gram
| ### Von zobel vn– ovch von harme vil chleider man da vant ### da wart vil wol gezieret manich arm vn– hant ### mit <bovgen> ob den siden die si da solden tragen ### iv enchvnde dizze vlizen zende niemen gesagen
###### 582 | ### Vil manigen gvrtel spæhen gvot vn– lanch ### vber vil richiv kleider manic wiziv hant do swanch ### vber roche ferrans vn– pfelle vz Arabin ### daz si in al der werlde bezzer nimmer chvnden sin
###### 583 | ### Ez wart in fver gespenge manic schoniv meit ### gen næt vil minnekliche ez moeht ir wesn leit ### der ir vil liehtiv varwe niht lvohte [22v]gegen der wat ### so schones ingesindes nv niht kuniges chvnne hat
###### 584 | ### Do die vil minneklichen nv trvgen ir gewant ### di si da fvren solden die chomen al zehant ### der hochgemvten rechen ein vil michel chraft ### man trvg ovch dar mit schilden vil manigen esschinen schaft

<<< Übersicht <<< vorige Seite nächste Seite >>>